@@ -355,17 +355,17 @@ class MultiAuth(object):
         return decorated
 
 class OAuth2(HTTPAuth):
-    def __init__(self, client_id, encryptionsecret, auth_url, redirect_url, auth_function, username_function, debug=None, scope=None): #pylint: disable=super-init-not-called
+    def __init__(self, client_id, auth_url, redirect_url, auth_function, username_function, debug=None, scope=None, userinfo_url=None): #pylint: disable=super-init-not-called
         def default_auth_error():
             return "Unauthorized Access (OAuth2)"
 
 
         self.client_id = client_id
-        self.encryptionsecret = encryptionsecret
         self.auth_url = auth_url #Remote URL
         self.auth_function = auth_function
         self.username_function = username_function
         self.redirect_url = redirect_url #the /login URL of the webservice
+        self.userinfo_url = userinfo_url
         self.scope = scope
         if debug:
             self.printdebug = debug
@@ -412,6 +412,7 @@ class OAuth2(HTTPAuth):
                         if self.scope:
                             kwargslogin['scope'] = self.scope
                         oauthsession = OAuth2Session(self.client_id, **kwargslogin)
+                        if self.userinfo_url: oauthsession.USERINFO_URL = self.userinfo_url
                         auth_url, state = self.auth_function(oauthsession, self.auth_url) #pylint: disable=unused-variable
                         kwargs['credentials'] = {'user': 'anonymous','401response': flask.redirect(auth_url)}
 
@@ -424,7 +425,9 @@ class OAuth2(HTTPAuth):
                         kwargs = {'redirect_uri': self.redirect_url}
                         if self.scope:
                             kwargs['scope'] = self.scope
+                        self.printdebug("OAuth2 details, client=" + self.client_id + ": " + repr(kwargs))
                         oauthsession = OAuth2Session(self.client_id, **kwargs)
+                        if self.userinfo_url: oauthsession.USERINFO_URL = self.userinfo_url
                         auth_url, state = self.auth_function(oauthsession, self.auth_url) #pylint: disable=unused-variable
 
                         #Redirect to Authentication Provider
@@ -432,20 +435,8 @@ class OAuth2(HTTPAuth):
 
                         return flask.redirect(auth_url)
                 else:
-                    #Decrypt access token
-                    try:
-                        oauth_access_token, ip = clam.common.oauth.decrypt(self.encryptionsecret, oauth_access_token)
-                    except clam.common.oauth.OAuthError:
-                        self.printdebug("Error decrypting access token")
-                        return self.auth_error_callback()
-                        #return flask.make_response("Error decrypting access token",403)
-
-                    if ip != flask.request.remote_addr:
-                        self.printdebug("Access token not valid for IP, got " + ip + ", expected " + flask.request.remote_addr)
-                        #return flask.make_response("Access token not valid for this IP",403)
-                        return self.auth_error_callback()
-
                     oauthsession = OAuth2Session(self.client_id, token={'access_token': oauth_access_token, 'token_type': 'bearer'})
+                    if self.userinfo_url: oauthsession.USERINFO_URL = self.userinfo_url
                     username = self.username_function(oauthsession)
                     if username:
                         #add (username, oauth_access_token) tuple as parameter to the wrapped function
